function scoreplot(scoredata)
% function scoreplot(scoredata)
%   scoreplot.m: plots score data as obtained from score_mn.m
%
%   --------------------------------INPUT------------------------------------
%   scoredata  =  The data structure from score_mn
%
%   Example:
%
%   See also: dosy_mn, score_mn, decra_mn, mcr_mn, varianimport,
%             brukerimport, jeolimport, peakpick_mn, dosyplot_mn,
%             dosyresidual, dosyplot_gui, scoreplot_mn, decraplot_mn,
%             mcrplot_mn
%
%   This is a part of the GNAT
%   Copyright  2017  <Mathias Nilsson>%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with this program; if not, write to the Free Software Foundation, Inc.,
%   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
%
%   Dr. Mathias Nilsson
%   School of Chemistry, University of Manchester,
%   Oxford Road, Manchester M13 9PL, UK
%   Telephone: +44 (0) 161 306 4465
%   Fax: +44 (0)161 275 4598
if nargin==0
    disp(' ')
    disp(' ')
    disp(' SCOREPLOT')
    disp('At least one input is needed')
    disp(' ')
    disp(' Type <<help mcrplot>> for more info')
    disp('  ')
    return
elseif nargin >3
    error(' Too many inputs')
end

% normalise the components
% for k=1:scoredata.ncomp+scoredata.nfix
%     scoredata.COMPONENTS(k,:)=scoredata.COMPONENTS(k,:)/norm(scoredata.COMPONENTS(k,:));
% end

% scoredata.COMPONENTS=scoredata.COMPONENTS./max(max(scoredata.COMPONENTS));

scoredata.Dval=[scoredata.Dval scoredata.Dfix];
scoredata.YScaling=1;


    %% ------------------------NORMAL SCORE plot---------------------
   hMain= figure('Color',[0.9 0.9 0.9],...
        'NumberTitle','Off',...
        'Name','SCORE');
           movegui(hMain,'northwest')

    
    ax1=zeros(1,(scoredata.ncomp+scoredata.nfix));
    ax2=zeros(1,(scoredata.ncomp+scoredata.nfix));
    for k=1:scoredata.ncomp+scoredata.nfix
        ax1(k)=subplot(scoredata.ncomp+scoredata.nfix,6,[(k-1)*6+1 (k-1)*6+4]);
        
        h=plot(scoredata.Ppmscale,scoredata.COMPONENTS(k,:),'Parent',ax1(k),'LineWidth',1);
        
        set(gca,'Xdir','reverse');
        axis('tight')
        ylim([(min(min(scoredata.COMPONENTS))-0.1*max(max(scoredata.COMPONENTS))) max(max(scoredata.COMPONENTS))*1.1])
        set(h,'LineWidth',1)
        set(gca,'LineWidth',1)
        if k==1
            title('\fontname{ariel} \bf SCORE components')
        end
        if k==scoredata.ncomp
            xlabel('\fontname{ariel} \bf Chemical shift /ppm');
        end
        
        ax2(k)=subplot(scoredata.ncomp+scoredata.nfix,6,[(k-1)*6+5 (k-1)*6+6]);
        plot(scoredata.Gzlvl.^2,scoredata.DECAYS(:,k)/max(scoredata.DECAYS(:,k)),'LineWidth',1,'Parent',ax2(k))
        xlim([-0.1 1])
        
        axis('tight')
        ylim('auto');
        set(h,'LineWidth',1);
        set(gca,'LineWidth',1);
        str=['\fontname{ariel} \bf D : ' num2str((scoredata.Dval(k)),3),' ', char(hex2dec('D7')) ,'10^{-10} m^{2} s^{-1} ' ];
        text(0.3*max(scoredata.Gzlvl.^2),0.9,str);
        str=['\fontname{ariel} \bf % : ' num2str(100*(scoredata.relp(k)/sum(scoredata.relp)),3)];
        text(0.3*max(scoredata.Gzlvl.^2),0.80,str);
        
        if k==scoredata.ncomp + scoredata.nfix
            xlabel('\fontname{ariel} \bf Gradient^2 /(T m^{-1})^2');
        end
    end
    set(ax1,'FontName','Arial','FontWeight','bold','LineWidth',2);
    set(ax2,'FontName','Arial','FontWeight','bold','LineWidth',2);
    linkaxes(ax1,'x');
    linkaxes(ax2,'x');

   %% ------------------------Plotting Diagnistics (Residuals etc )---------------------
   
   if scoredata.diags==1
       % Residuals
      hResid= figure('Color',[0.9 0.9 0.9],...
           'NumberTitle','Off',...
           'Name','Residual variance');
       movegui(hResid,'southwest')
       
       axres(1)=subplot(1,6,[1,4]);
       plot(scoredata.Ppmscale,stdnan(scoredata.RESIDUALS').^2)
       ylabel('Residual variance');
       xlabel('\fontname{ariel} \bf Chemical shift /ppm');
       set(gca,'Xdir','reverse');       
       
       axres(2)=subplot(1,6,[5,6]);
       plot(scoredata.Gzlvl.^2,stdnan(scoredata.RESIDUALS).^2)
       hold on
       plot(scoredata.Gzlvl.^2,stdnan(scoredata.RESIDUALS).^2,'r+')
       ylabel('Residual variance');
       xlabel('\fontname{ariel} \bf Gradient^2 /T m^{-1}^2');
       movegui(hResid,'southeast')
       
       %Leverages
      hLev=  figure('Color',[0.9 0.9 0.9],...
           'NumberTitle','Off',...
           'Name','Leverage');
       movegui(hLev,'south')
       axlev(1)=subplot(1,6,[1,4]);
       T=scoredata.COMPONENTS';
       h1=diag(T*pinv(T'*T)*T');
       plot(scoredata.Ppmscale,h1,'+','color','black')
       ylabel('Leverage');
       xlabel('\fontname{ariel} \bf Chemical shift /ppm');
       for i=1:length(h1)
           text(scoredata.Ppmscale(i),h1(i),num2str(i))
       end
       set(gca,'Xdir','reverse');
       
       axlev(2)=subplot(1,6,[5,6]);
       P=scoredata.DECAYS;
       h2=diag(P*P');
       plot(scoredata.Gzlvl.^2,h2)
       St=scoredata.Gzlvl.^2;
       for i=1:length(h2)
           text(St(i),h2(i),num2str(i))
       end
       ylabel('Leverage');
       xlabel('\fontname{ariel} \bf Gradient^2 /T m^{-1}^2');
       
       %Leverages vs. Resduals
       
     hLevResid=  figure('Color',[0.9 0.9 0.9],...
           'NumberTitle','Off',...
           'Name','Leverage vs, Residual');
       movegui(hLevResid,'southwest')
       
       axlev(1)=subplot(1,6,[1,4]);
       r1=stdnan(scoredata.RESIDUALS');
       plot(h1,r1,'+','color','black')
       ylabel('Standard deviation');
       xlabel('Leverage');
       for i=1:length(r1)
           text(h1(i),r1(i),num2str(i))
       end
       
       axlev(2)=subplot(1,6,[5,6]);
       r2=stdnan(scoredata.RESIDUALS);
       plot(h2,r2,'+','color','black')
       for i=1:length(r2)
           text(h2(i),r2(i),num2str(i))
       end
       xlabel('Leverage');





%        % Residuals
%        figure('Color',[0.9 0.9 0.9],...
%            'NumberTitle','Off',...
%            'Name','Residuals');
%        
%         VertOff=10
%         HorizOff=2
%    
%         Horiz=round(HorizOff*scoredata.np/100);
%         np=scoredata.np
%         arraydim=scoredata.ngrad
%         
%         plotresid=nan(np+abs(Horiz)*arraydim,arraydim);
%         plotspec=nan(np+abs(Horiz)*arraydim,arraydim);
%         plotspecresid=nan(np+abs(Horiz)*arraydim,arraydim*2);
%         if Horiz<0
%             for k=1:arraydim
%                 plotresid((k-1)*abs(Horiz)+1:np+(k-1)*abs(Horiz),k)=real(scoredata.RESIDUALS(:,k));
%                 plotspec((k-1)*abs(Horiz)+1:np+(k-1)*abs(Horiz),k)=real(scoredata.SPECTRA(:,k));
%             end
%         else
%             for k=1:arraydim
%                 plotresid((k-1)*abs(Horiz)+1:np+(k-1)*abs(Horiz),arraydim-k+1)=real(scoredata.RESIDUALS(:,arraydim-k+1));
%                 plotspec((k-1)*abs(Horiz)+1:np+(k-1)*abs(Horiz),arraydim-k+1)=real(scoredata.SPECTRA(:,arraydim-k+1));
%                 
%             end
%         end
%         scalefact=max(max(plotspec))/max(max(plotresid));
%         scalefact=scalefact/5;%residuals at 20% of spectra
%         plotresid=plotresid*scalefact; 
%         VertIncr=VertOff*max(max(plotresid))/100;
%         for k=1:arraydim
%             plotresid(:,k)=plotresid(:,k)+(k-1)*VertIncr;
%             plotspec(:,k)=plotspec(:,k)+(k-1)*VertIncr;
%             plotspecresid(:,(2*k-1))=plotspec(:,k)+(k-1)*VertIncr;
%           
%           
%            plotspecresid(:,2*k)=plotresid(:,k)+(k-1)*VertIncr;
%         end
% %         for k=1:arraydim
% %    
% %             plotspecresid(:,k)=plotspec(:,k)+(k-1)*VertIncr;
% %         end
% %         
% 
%         plot(plotresid,'Color','Red');
%         set(gca,'Xdir','reverse');
%         
%         
%                figure('Color',[0.9 0.9 0.9],...
%            'NumberTitle','Off',...
%            'Name','Raw data');
%         
%          plot(plotspec,'Color','Black');
%          
%          
%         set(gca,'Xdir','reverse');
%                    figure('Color',[0.9 0.9 0.9],...
%            'NumberTitle','Off',...
%            'Name','Raw data and residuals');
%        
%         plot(plotspecresid,'Color','Green');
%        
%        plot(plotspecresid(:,2:2:(arraydim*2)),'Color','red');
%        hold on
%        plot(1*plotspecresid(:,1:2:(arraydim*2)),'Color','black');
%        hold off
%        xlabel(['Residuals multiplied by: ' num2str(0.1*round(scalefact*10))]);
%         *10
%          plot(plotspec,'Color','Black');
%          hold on
%          plot(plotresid*10,'Color','Red');
%          hold off
  %      set(gca,'Xdir','reverse');


% 
%        % Testing plotting as separate axes
%       FigSize=[5 5 20 20]
%        hFigSpec= figure('Color',[1 1 1 1],...
%            'NumberTitle','Off',...
%            'Units','Centimeters',...
%            'Position',FigSize,...
%            'Name','Spectra');
%        axis('off')
%        
%        % nSpec=10
%        nSpec=scoredata.ngrad
%        
%        HorizOffset=0.1
%        PlotWidth=FigSize(3)-HorizOffset*nSpec
%         PlotHeight=FigSize(4)/2
%        VertOffset=FigSize(4)/(nSpec*1.1)
%       % HorizOffset=1
%        
%       % PlotWidth=10
%       % PlotHeight=10
%        VertScaleSpec=1
%        VertScaleResid=1
%        
%        %Plot the spectra
%        hold off
%        for k=1:nSpec           
%            
%            hSpec=axes(hFigSpec,...
%                'Units','Centimeters',...
%                'Box','Off',...
%                'Position',[k*HorizOffset k*VertOffset PlotWidth PlotHeight]);
%            
%       
%            plot(scoredata.SPECTRA(:,k));
%            if k==1
%                ylim_first_spec=ylim()/VertScaleSpec;
%            end
%            ylim(ylim_first_spec);
%            axis(hSpec,'off')
%            hold on
%            
%        end
%        hold off
%        
%        
%               
%        hFigResid= figure('Color',[1 1 1 1],...
%            'NumberTitle','Off',...
%            'Units','Centimeters',...
%            'Position',[5 5 20 20],...
%            'Name','Residuals');
%        axis('off')
%        
%        % Calculate number of data points for 1 Horizontal offset
%        
%        HOpoints=ceil(HorizOffset*scoredata.np/PlotWidth)
%        
%        PlotSpec=nan(scoredata.np+HOpoints*nSpec,nSpec);
%        for k=1:nSpec
%            PlotSpec((k-1)*HOpoints+1:scoredata.np+(k-1)*HOpoints,nSpec-k+1)=...
%                real(scoredata.SPECTRA(:,nSpec-k+1));           
%        end
%        
%        % Calculate vertical offset 
%        
%        Vscale=[min(min(scoredata.SPECTRA)) max(max(scoredata.SPECTRA))];
%         Vscale2=[min(min(scoredata.RESIDUALS)) max(max(scoredata.RESIDUALS))];
%       %Voff=0.5 %cm  
%       Voffset=  (Vscale(2)-Vscale(1))/(nSpec+1)
%        
%         for k=1:nSpec
%            PlotSpec(:,k)= PlotSpec(:,k)+(k)*Voffset;
%                          
%         end
%        plot(0.5*PlotSpec,'color','black')
%        ylim(Vscale)
      
        %plotresid=nan(np+abs(Horiz)*arraydim,arraydim);
%         plotspec=nan(np+abs(Horiz)*arraydim,arraydim);
%         plotspecresid=nan(np+abs(Horiz)*arraydim,arraydim*2);
%         if Horiz<0
%             for k=1:arraydim
%                 plotresid((k-1)*abs(Horiz)+1:np+(k-1)*abs(Horiz),k)=real(scoredata.RESIDUALS(:,k));
%                 plotspec((k-1)*abs(Horiz)+1:np+(k-1)*abs(Horiz),k)=real(scoredata.SPECTRA(:,k));
%             end
%         else
%             for k=1:arraydim
%                 plotresid((k-1)*abs(Horiz)+1:np+(k-1)*abs(Horiz),arraydim-k+1)=real(scoredata.RESIDUALS(:,arraydim-k+1));
%                 plotspec((k-1)*abs(Horiz)+1:np+(k-1)*abs(Horiz),arraydim-k+1)=real(scoredata.SPECTRA(:,arraydim-k+1));
%                 
%             end
%         end
%         scalefact=max(max(plotspec))/max(max(plotresid));
%         scalefact=scalefact/5;%residuals at 20% of spectra
%         plotresid=plotresid*scalefact; 
%         VertIncr=VertOff*max(max(plotresid))/100;
%         for k=1:arraydim
%             plotresid(:,k)=plotresid(:,k)+(k-1)*VertIncr;
%             plotspec(:,k)=plotspec(:,k)+(k-1)*VertIncr;
%             plotspecresid(:,(2*k-1))=plotspec(:,k)+(k-1)*VertIncr;
%           
%           
%            plotspecresid(:,2*k)=plotresid(:,k)+(k-1)*VertIncr;
%         end
% %         for k=1:arraydim
% %    
% %             plotspecresid(:,k)=plotspec(:,k)+(k-1)*VertIncr;
% %         end
% %         
% 
%         plot(plotresid,'Color','Red');
%         set(gca,'Xdir','reverse');
       
       
       
%        hFigResid= figure('Color',[1 1 1 1],...
%            'NumberTitle','Off',...
%            'Units','Centimeters',...
%            'Position',[5 5 20 20],...
%            'Name','Residuals');
%        axis('off')
% 
%      %  max(max(abs(scoredata.RESIDUALS)))
%        
%       scaleFac= max(abs(ylim_first_spec))/max(max(abs(scoredata.RESIDUALS)))
%        
%        ylim_first_resid=ylim_first_spec/(0.5*scaleFac)
%        for k=1:nSpec
%            axis('off')
%            axes(hFigResid,...
%                'Units','Centimeters',...
%                'Box','Off',...
%                'Position',[k*HorizOffset k*VertOffset PlotWidth PlotHeight]);
%            axis('off')
%            plot(scoredata.RESIDUALS(:,k),'red');
%            ylim(ylim_first_resid);
%            axis('off')
%             hold on
%            
%        end
%        ylim_first_resid
%        ylim_first_spec
% 
%        hold off
% %        set(hP
% %        hPlot=plot(hAxes,scoredata.RESIDUALS(:,1));
% %        set(hPlot, 'Units','Centimeters',...
% %            'Position',[0 0 12 5]);
       
       
       
   end
   
   
end

